@@ -66,7 +66,7 @@ def change_sec_to_ffmpeg_time_format(time_input):
 def main():
     parser = argparse.ArgumentParser(prog='pim_video',
                                      description='PIM_VIDEO package.')
-    parser.add_argument('--version', action='version', version='1.0.1'),
+    parser.add_argument('--version', action='version', version='1.0.2'),
     parser.add_argument("-d", dest="input_directory", required=True, default=sys.stdin,
                         help="directory folder to be processed", metavar="directory name")
 
@@ -100,11 +100,11 @@ def main():
             ffmpeg_check_cmd = "ffmpeg -version"
             try:
                 ffmpeg_check_output = subprocess.check_output(ffmpeg_check_cmd)
-            except FileNotFoundError:
-                ffmpeg_check_output = "not found"
-            try:
-                is_there_ffmpeg = "not " not in ffmpeg_check_output.decode('utf-8')
-            except AttributeError:
+                ffmpeg_check_output = ffmpeg_check_output.decode('utf-8')
+                print(ffmpeg_check_output)
+                is_there_ffmpeg = True
+            except Exception as error:
+                print(error)
                 is_there_ffmpeg = False
 
             if is_there_ffmpeg:
